==> e107-0.7.20.tbz: www/e107/e107_plugins/poll/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/poll/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("POLL_ADLAN01", "Poll");
define("POLL_ADLAN02", "The poll plugin allows you to define polls in either a menu or forum post.");
define("POLL_ADLAN03", "Configure polls");
define("POLL_ADLAN04", "The poll plugin has been successfully installed. To add polls, click on the Polls icon in the plugin section of your admin front page, and remember to activate the menu item from your menus page.");

define("POLL_ADLAN05", "Main Poll: ");
define("POLL_ADLAN06", "Forum Thread: ");
define("POLL_ADLAN07", "Type");

define("POLLAN_MENU_CAPTION", "Poll");

define("POLLAN_1", "Existing polls");
define("POLLAN_2", "Create / edit polls");
define("POLLAN_3", "Poll question");
define("POLLAN_4", "Options");
define("POLLAN_5", "Edit");
define("POLLAN_6", "Delete");
define("POLLAN_7", "No polls yet.");
define("POLLAN_8", "Add another option");
define("POLLAN_9", "Allow multiple choices?");
define("POLLAN_10", "yes");
define("POLLAN_11", "no");
define("POLLAN_12", "Show results");
define("POLLAN_13", "after voting");
define("POLLAN_14", "by clicking view results link - comments must be turned on to use this option");
define("POLLAN_15", "Allow to vote on this poll");
define("POLLAN_16", "Vote storage method");
define("POLLAN_17", "cookie");
define("POLLAN_18", "IP address");
define("POLLAN_19", "User ID (only members can vote)");
define("POLLAN_20", "Allow comments to be posted to this poll?");
define("POLLAN_21", "Preview again");
define("POLLAN_22", "Update Poll");
define("POLLAN_23", "Create Poll");
define("POLLAN_24", "Preview");
define("POLLAN_25", "Clear form");
define("POLLAN_26", "votes");
define("POLLAN_27", "Comments");
define("POLLAN_28", "Previous polls");
define("POLLAN_29", "posted by");
define("POLLAN_30", "Submit");
define("POLLAN_31", "Votes");
define("POLLAN_32", "Click here to see results");
define("POLLAN_33", "No previous polls yet.");
define("POLLAN_34", "Title");
define("POLLAN_35", "Posted by");
define("POLLAN_36", "Active");
define("POLLAN_37", "active from");
define("POLLAN_38", "to");
define("POLLAN_39", "Thank you for voting!");
define("POLLAN_40", "Click here to see results");
define("POLLAN_41", "This poll is restricted to members only");
define("POLLAN_42", "This poll is restricted to administrators only");
define("POLLAN_43", "You do not have the required permissions to vote in this poll");
define("POLLAN_44", "Delete this poll?");
define("POLLAN_45", "Poll successfully updated");
define("POLLAN_46", "Field(s) left blank");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/poll/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/poll/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("POLL_ADLAN01", "Poll");
define("POLL_ADLAN02", "The poll plugin allows you to define polls in either a menu or forum post.");
define("POLL_ADLAN03", "Configure polls");
define("POLL_ADLAN04", "The poll plugin has been successfully installed. To add polls, click on the Polls icon in the plugin section of your admin front page, and remember to activate the menu item from your menus page.");

define("POLL_ADLAN05", "Main Poll: ");
define("POLL_ADLAN06", "Forum Thread: ");
define("POLL_ADLAN07", "Type");

define("POLLAN_MENU_CAPTION", "Poll");

define("POLLAN_1", "Existing polls");
define("POLLAN_2", "Create / edit polls");
define("POLLAN_3", "Poll question");
define("POLLAN_4", "Options");
define("POLLAN_5", "Edit");
define("POLLAN_6", "Delete");
define("POLLAN_7", "No polls yet.");
define("POLLAN_8", "Add another option");
define("POLLAN_9", "Allow multiple choices?");
define("POLLAN_10", "yes");
define("POLLAN_11", "no");
define("POLLAN_12", "Show results");
define("POLLAN_13", "after voting");
define("POLLAN_14", "by clicking view results link - comments must be turned on to use this option");
define("POLLAN_15", "Allow to vote on this poll");
define("POLLAN_16", "Vote storage method");
define("POLLAN_17", "cookie");
define("POLLAN_18", "IP address");
define("POLLAN_19", "User ID (only members can vote)");
define("POLLAN_20", "Allow comments to be posted to this poll?");
define("POLLAN_21", "Preview again");
define("POLLAN_22", "Update Poll");
define("POLLAN_23", "Create Poll");
define("POLLAN_24", "Preview");
define("POLLAN_25", "Clear form");
define("POLLAN_26", "votes");
define("POLLAN_27", "Comments");
define("POLLAN_28", "Previous polls");
define("POLLAN_29", "posted by");
define("POLLAN_30", "Submit");
define("POLLAN_31", "Votes");
define("POLLAN_32", "Click here to see results");
define("POLLAN_33", "No previous polls yet.");
define("POLLAN_34", "Title");
define("POLLAN_35", "Posted by");
define("POLLAN_36", "Active");
define("POLLAN_37", "active from");
define("POLLAN_38", "to");
define("POLLAN_39", "Thank you for voting!");
define("POLLAN_40", "Click here to see results");
define("POLLAN_41", "This poll is restricted to members only");
define("POLLAN_42", "This poll is restricted to administrators only");
define("POLLAN_43", "You do not have the required permissions to vote in this poll");
define("POLLAN_44", "Delete this poll?");
define("POLLAN_45", "Poll successfully updated");
define("POLLAN_46", "Field(s) left blank");

?>
